from ..api_base import ApiBase


class ExpensesCustomFields(ApiBase):
    """Class for Expenses Custom Fields APIs."""

    POST_EXPENSE_CUSTOM_FIELDS = '/api/tpa/v1/expenses_custom_fields'
    GET_EXPENSES_CUSTOM_FIELDS = '/api/tpa/v1/expenses_custom_fields'

    def post(self, data):
        """Create Custom Field for an organization

        Parameters:
            data (dict): Dict of Custom Field Schema

        Returns:
            Dict with Expense Custom Field Id
        """

        return self._post_request(data, ExpensesCustomFields.POST_EXPENSE_CUSTOM_FIELDS)

    def get(self, active=None, **kwargs):
        """Get a list of expenses input field matching the parameters.

        Parameters:
            active (boolean): To get the active fields only (optional)

        Returns:
            List with dicts in ExpenseCustomFields schema.
        """
        return self._get_request({
            'active': active,
            **kwargs
        }, ExpensesCustomFields.GET_EXPENSES_CUSTOM_FIELDS)
